/*
 * *************************************************
 * Copyright (c) 2018 QMTH. All Rights Reserved.
 * Created by Deason on 2018-10-17 16:31:14.
 * *************************************************
 */

package cn.com.qmth.examcloud.core.print.service.impl;

import cn.com.qmth.examcloud.core.print.common.jpa.OrderBuilder;
import cn.com.qmth.examcloud.core.print.common.jpa.SearchBuilder;
import cn.com.qmth.examcloud.core.print.common.jpa.SpecUtils;
import cn.com.qmth.examcloud.core.print.common.utils.Check;
import cn.com.qmth.examcloud.core.print.entity.PrintingProject;
import cn.com.qmth.examcloud.core.print.repository.PrintingProjectRepository;
import cn.com.qmth.examcloud.core.print.service.PrintingProjectService;
import cn.com.qmth.examcloud.core.print.service.bean.PrintingProjectConvert;
import cn.com.qmth.examcloud.core.print.service.bean.PrintingProjectInfo;
import cn.com.qmth.examcloud.core.print.service.bean.PrintingProjectQuery;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.data.jpa.domain.Specification;
import org.springframework.stereotype.Service;

/**
 * 印刷项目相关接口
 *
 * @author: fengdesheng
 * @since: 2018/10/17
 */
@Service
public class PrintingProjectServiceImpl implements PrintingProjectService {
    @Autowired
    private PrintingProjectRepository printingProjectRepository;

    @Override
    public Page<PrintingProjectInfo> getPrintingProjectList(PrintingProjectQuery query) {
        Check.isNull(query, "查询参数不能为空！");
        //查询条件
        SearchBuilder searches = new SearchBuilder();
        if (query.getOrgId() != null) {
            searches.eq("orgId", query.getOrgId());
        }
        if (query.getExamId() != null) {
            searches.eq("examId", query.getExamId());
        }
        if (query.getPmId() != null) {
            searches.eq("pmId", query.getPmId());
        }
        if (query.getSupplierId() != null) {
            searches.eq("supplierId", query.getSupplierId());
        }
        Specification<PrintingProject> spec = SpecUtils.buildSearchers(PrintingProject.class, searches.build());
        //排序条件
        OrderBuilder orders = new OrderBuilder().desc("id");
        //分页条件
        Pageable pageable = SpecUtils.buildPageable(query.getPageNo(), query.getPageSize(), orders.build());
        Page<PrintingProject> page = printingProjectRepository.findAll(spec, pageable);
        return PrintingProjectConvert.ofPage(page);
    }

    @Override
    public void savePrintingProject(PrintingProjectInfo info) {
        PrintingProject entity = PrintingProjectConvert.of(info);
        Check.isNull(entity.getOrgId(), "学校机构ID不能为空！");
        Check.isNull(entity.getExamId(), "考试ID不能为空！");
        printingProjectRepository.save(entity);
    }

}